pub struct Digest(/* private fields */);Expand description
Hashing wrapper type.
Implementations
Sourceimpl Digest
impl Digest
Sourcepub fn iterated(
salt: &[u8],
bytes: &[u8],
type: DigestType,
iterations: u16,
) -> Result<Digest, ProtoError>
pub fn iterated( salt: &[u8], bytes: &[u8], type: DigestType, iterations: u16, ) -> Result<Digest, ProtoError>
Hashes the given data iterations times with the given salt and r#type.
Sourcepub fn from_iter<'a>(
bytes: impl IntoIterator<Item = &'a [u8]>,
type: DigestType,
) -> Result<Digest, ProtoError>
pub fn from_iter<'a>( bytes: impl IntoIterator<Item = &'a [u8]>, type: DigestType, ) -> Result<Digest, ProtoError>
Hashes the data from the bytes iterator with the given r#type.
Sourcepub fn new(bytes: &[u8], type: DigestType) -> Result<Digest, ProtoError>
pub fn new(bytes: &[u8], type: DigestType) -> Result<Digest, ProtoError>
Hashes