#[non_exhaustive]pub enum DnsSecError {
HmacInvalid,
Message(&'static str),
Msg(String),
Proto(ProtoError),
RingKeyRejected(KeyRejected),
RingUnspecified(Unspecified),
TsigUnsupportedMacAlgorithm(TsigAlgorithm),
TsigWrongKey,
}Expand description
The error kind for dnssec errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
HmacInvalid
An HMAC failed to verify
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
Proto(ProtoError)
An error got returned by the hickory-proto crate
RingKeyRejected(KeyRejected)
A ring error
RingUnspecified(Unspecified)
A ring error
TsigUnsupportedMacAlgorithm(TsigAlgorithm)
Tsig unsupported mac algorithm
Supported algorithm documented in TsigAlgorithm::supported function.
TsigWrongKey
Tsig key verification failed