pub struct ProofError {
pub proof: Proof,
pub kind: ProofErrorKind,
}Expand description
The error type for dnssec errors that get returned in the crate
Fields
proof: ProofThe proof derived from the failed state
kind: ProofErrorKindThe kind of error
Implementations
Sourceimpl ProofError
impl ProofError
Sourcepub fn new(proof: Proof, kind: ProofErrorKind) -> ProofError
pub fn new(proof: Proof, kind: ProofErrorKind) -> ProofError
Create an error with the given Proof and Associated Error
Sourcepub fn kind(&self) -> &ProofErrorKind
pub fn kind(&self) -> &ProofErrorKind
Get the kind of the error
Sourcepub fn ds_should_exist(name: Name) -> ProofError
pub fn ds_should_exist(name: Name) -> ProofError
Returns an error related to the absence of a DS record