pub struct TBS(/* private fields */);Expand description
Data To Be Signed.
Implementations
Sourceimpl TBS
impl TBS
Sourcepub fn from_input<'a>(
name: &Name,
dns_class: DNSClass,
input: &SigInput,
records: impl Iterator<Item = &'a Record>,
) -> Result<TBS, ProtoError>
pub fn from_input<'a>( name: &Name, dns_class: DNSClass, input: &SigInput, records: impl Iterator<Item = &'a Record>, ) -> Result<TBS, ProtoError>
Returns the to-be-signed serialization of the given record set using the information provided from the SIG record.
Arguments
name- labels of the record to signdns_class- DNSClass of the RRSet, i.e. INinput-SigInputdata used to create the signaturerecords- RRSet records to sign with the information in therrsig
Return
binary hash of the RRSet with the information from the RRSIG record