SigningKey

Trait SigningKey 

pub trait SigningKey:
    Send
    + Sync
    + 'static {
    // Required methods
    fn sign(&self, tbs: &TBS) -> Result<Vec<u8>, DnsSecError>;
    fn to_public_key(&self) -> Result<PublicKeyBuf, DnsSecError>;
    fn algorithm(&self) -> Algorithm;
}
A key that can be used to sign records.

Required Methods

fn sign(&self, tbs: &TBS) -> Result<Vec<u8>, DnsSecError>

Sign DNS records.

Return value

The signature, ready to be stored in an RData::RRSIG.

fn to_public_key(&self) -> Result<PublicKeyBuf, DnsSecError>

Returns a PublicKeyBuf for this SigningKey.

fn algorithm(&self) -> Algorithm

Returns the algorithm of the key.

Implementors