pub struct SigInput {
pub type_covered: RecordType,
pub algorithm: Algorithm,
pub num_labels: u8,
pub original_ttl: u32,
pub sig_expiration: SerialNumber,
pub sig_inception: SerialNumber,
pub key_tag: u16,
pub signer_name: Name,
}Expand description
Input for a SIG or RRSIG record signature.
Fields
type_covered: RecordTypeRecordType which this signature covers, should be NULL for SIG(0).
algorithm: AlgorithmAlgorithm used to generate the signature.
num_labels: u8Number of labels in the name, should be less 1 for *.name labels, see
Name::num_labels().
original_ttl: u32- TTL for the RRSet stored in the zone, should be 0 for SIG(0).
sig_expiration: SerialNumberTimestamp at which this signature is no longer valid
Very important to keep this low, < +5 minutes to limit replay attacks.
sig_inception: SerialNumber- Timestamp when this signature was generated.
key_tag: u16- See the key_tag generation in
rr::dnssec::Signer::key_tag().
signer_name: Name- Domain name of the server which was used to generate the signature.
Implementations
Sourceimpl SigInput
impl SigInput
Sourcepub fn from_rrset(
rr_set: &RecordSet,
expiration: OffsetDateTime,
inception: OffsetDateTime,
signer: &DnssecSigner,
) -> Result<SigInput, ProtoError>
pub fn from_rrset( rr_set: &RecordSet, expiration: OffsetDateTime, inception: OffsetDateTime, signer: &DnssecSigner, ) -> Result<SigInput, ProtoError>
Create a new SigInput from the given input parameters.